"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const base_command_1 = require("../base-command");
const command_1 = require("../utils/command");
const examples_1 = require("../utils/examples");
const COMMAND_NAME = command_1.fileName(__filename);
class IndexSizeCommand extends base_command_1.default {
    getQuery() {
        return `
      SELECT c.relname AS name,
        pg_size_pretty(sum(c.relpages::bigint*8192)::bigint) AS size
      FROM pg_class c
      LEFT JOIN pg_namespace n ON (n.oid = c.relnamespace)
      WHERE n.nspname NOT IN ('pg_catalog', 'information_schema')
      AND n.nspname !~ '^pg_toast'
      AND c.relkind='i'
      GROUP BY c.relname
      ORDER BY sum(c.relpages) DESC;`;
    }
}
IndexSizeCommand.description = 'Show the size of indexes, descending by size.';
IndexSizeCommand.examples = [command_1.defaultExample(COMMAND_NAME), examples_1.INDEX_SIZE];
IndexSizeCommand.usage = [command_1.defaultUsage(COMMAND_NAME)];
exports.default = IndexSizeCommand;
