"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const base_command_1 = require("../base-command");
const command_1 = require("../utils/command");
const COMMAND_NAME = command_1.fileName(__filename);
class IndexUsageCommand extends base_command_1.default {
    getQuery() {
        return `
      SELECT
        schemaname AS schema,
        relname AS name,
        CASE idx_scan
          WHEN 0 THEN 'Insufficient data'
          ELSE (100 * idx_scan / (seq_scan + idx_scan))::text
        END percent_of_times_index_used,
        n_live_tup rows_in_table
      FROM
        pg_stat_user_tables
      ORDER BY
        n_live_tup DESC;`;
    }
}
IndexUsageCommand.description = 'Calculates your index hit rate (effective databases are at 99% and up).';
IndexUsageCommand.examples = [command_1.defaultExample(COMMAND_NAME)];
IndexUsageCommand.usage = [command_1.defaultUsage(COMMAND_NAME)];
exports.default = IndexUsageCommand;
