"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@oclif/command");
const base_command_1 = require("../base-command");
const command_2 = require("../utils/command");
const COMMAND_NAME = command_2.fileName(__filename);
const DEFAULT_LOCK_MODE = 'ExclusiveLock';
const SUPPORTED_LOCKS_MODE = [
    'AccessShareLock',
    'RowShareLock',
    'RowExclusiveLock',
    'ShareUpdateExclusiveLock',
    'ShareLock',
    'ShareRowExclusiveLock',
    'ExclusiveLock',
    'AccessExclusiveLock',
    'all'
];
class LocksCommand extends base_command_1.default {
    getClass() {
        return LocksCommand;
    }
    getQuery(_, flags) {
        let values = [];
        let truncatedQueryString = (prefix) => {
            let column = `${prefix}query`;
            if (flags.truncate) {
                return `CASE WHEN length(${column}) <= 40 THEN ${column} ELSE substr(${column}, 0, 39) || '…' END`;
            }
            else {
                return column;
            }
        };
        let whereLocksMode = '';
        if (isAll(flags.locks)) {
            whereLocksMode = 'AND pg_locks.mode = $1';
            values.push(flags.lock);
        }
        let query = `
      SELECT
        pg_stat_activity.pid,
        pg_class.relname,
        pg_locks.transactionid,
        pg_locks.granted,
        ${truncatedQueryString('pg_stat_activity.')} AS query_snippet,
        age(now(),pg_stat_activity.query_start) AS "age"
      FROM pg_stat_activity,pg_locks left
      OUTER JOIN pg_class
        ON (pg_locks.relation = pg_class.oid)
      WHERE pg_stat_activity.query <> '<insufficient privilege>'
        AND pg_locks.pid = pg_stat_activity.pid
        ${whereLocksMode}
        AND pg_stat_activity.pid <> pg_backend_pid() order by query_start;
    `;
        return { text: query, values };
    }
}
LocksCommand.description = 'Display queries with active locks.';
LocksCommand.examples = [command_2.defaultExample(COMMAND_NAME)];
LocksCommand.usage = [command_2.defaultUsage(COMMAND_NAME)];
LocksCommand.flags = Object.assign({}, base_command_1.DEFAULT_CONNECTION_FLAGS, { truncate: command_1.flags.boolean({
        char: 't',
        description: 'truncate query'
    }), lock: command_1.flags.enum({
        char: 'l',
        description: `lock mode, one of (${SUPPORTED_LOCKS_MODE.join('|')})`,
        helpValue: 'LOCK',
        default: DEFAULT_LOCK_MODE,
        options: SUPPORTED_LOCKS_MODE
    }) });
exports.default = LocksCommand;
function isAll(type) {
    return type === 'all';
}
