"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const base_command_1 = require("../base-command");
const command_1 = require("../utils/command");
const COMMAND_NAME = command_1.fileName(__filename);
class LongRunningCommands extends base_command_1.default {
    getQuery() {
        return `
      SELECT
        pid,
        now() - pg_stat_activity.query_start AS duration,
        query AS query
      FROM
        pg_stat_activity
      WHERE
        pg_stat_activity.query <> ''::text
        AND state <> 'idle'
        AND now() - pg_stat_activity.query_start > interval '5 minutes'
      ORDER BY
        now() - pg_stat_activity.query_start DESC;`;
    }
}
LongRunningCommands.description = 'Show all queries longer than five minutes by descending duration.';
LongRunningCommands.examples = [command_1.defaultExample(COMMAND_NAME)];
LongRunningCommands.usage = [command_1.defaultUsage(COMMAND_NAME)];
exports.default = LongRunningCommands;
