"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const base_command_1 = require("../base-command");
const command_1 = require("../utils/command");
const COMMAND_NAME = command_1.fileName(__filename);
class TotalIndexSizeCommand extends base_command_1.default {
    getQuery() {
        return `
      SELECT pg_size_pretty(sum(c.relpages::bigint*8192)::bigint) AS size
      FROM pg_class c
      LEFT JOIN pg_namespace n
        ON (n.oid = c.relnamespace)
      WHERE n.nspname NOT IN ('pg_catalog', 'information_schema') AND
            n.nspname !~ '^pg_toast' AND
            c.relkind='i';`;
    }
}
TotalIndexSizeCommand.description = 'Show the total size of all indexes in MB.';
TotalIndexSizeCommand.examples = [command_1.defaultExample(COMMAND_NAME)];
TotalIndexSizeCommand.usage = [command_1.defaultUsage(COMMAND_NAME)];
exports.default = TotalIndexSizeCommand;
