"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const base_command_1 = require("../base-command");
const command_1 = require("../utils/command");
const COMMAND_NAME = command_1.fileName(__filename);
class TotalTableSizeCommand extends base_command_1.default {
    getQuery() {
        return `
      SELECT c.relname AS name,
             pg_size_pretty(pg_total_relation_size(c.oid)) AS size
      FROM pg_class c
      LEFT JOIN pg_namespace n
        ON (n.oid = c.relnamespace)
      WHERE n.nspname NOT IN ('pg_catalog', 'information_schema') AND
            n.nspname !~ '^pg_toast' AND
            c.relkind='r'
      ORDER BY pg_total_relation_size(c.oid) DESC;`;
    }
}
TotalTableSizeCommand.description = 'Show the size of the tables (including indexes), descending by size.';
TotalTableSizeCommand.examples = [command_1.defaultExample(COMMAND_NAME)];
TotalTableSizeCommand.usage = [command_1.defaultUsage(COMMAND_NAME)];
exports.default = TotalTableSizeCommand;
