import { Client, QueryResult, QueryConfig } from 'pg';
export declare type Client = Client;
export declare type QueryResult = QueryResult;
export declare const DEFAULT_HOST = "localhost";
export declare const DEFAULT_PORT = 5432;
export declare const DEFAULT_DBNAME = "postgres";
export declare const DEFAULT_USERNAME: string;
/**
 * Connects to a postgres database.
 *
 * @param host Host. Default: localhost
 * @param port Port number. Default: 5432
 * @param database Database name. Default: postgres
 * @param user Optional username.
 * @param password Optional password
 * @returns Pg client.
 */
export declare function connect(host?: string, port?: number, database?: string, user?: string, password?: string): Promise<Client>;
/**
 * Executes a query given a client.
 *
 * @param client Client.
 * @param query Query string or query object.
 */
export declare function query(client: Client, query: string | QueryConfig): Promise<QueryResult>;
/**
 * Assert specific extension is present and installed.
 *
 * @param client Client.
 * @param schemaName Schema name.
 * @param extensionName Extension name.
 */
export declare function assertExtensionPresent(client: Client, schemaName: string, extensionName: string): Promise<void>;
/**
 * Sets the active schema.
 *
 * @param client Client
 * @param schemaName Schema name.
 */
export declare function setActiveSchema(client: Client, schemaName: string): Promise<void>;
/**
 * Formats the query string.
 *
 * @param query Query string.
 * @param values Query parts.
 */
export declare function format(query: string, values: any[]): any;
